Credits
=======

* `Tycho Tatitscheff <mailto://tycho.tatitscheff+saruman@gadz.org>`_ (Nelen & Schuurmans) is the
  originator and main author.

* `Zest software <http://zestsoftware.nl>`_ for their releases manager and also for inspiration (copy paste of most docs).
